==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/GetCSVSummaryInteractions.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetCSVSummaryInteractions] 
(
	@VCC					VARCHAR(50) = NULL,
	@StartDate				DATETIME = '1980-01-01T00:00:00',
    @EndDate				DATETIME = '2050-01-01T23:59:59',
	@StartHour				VARCHAR(50) = NULL,
	@EndHour				VARCHAR(50) = NULL,
	@MinDuration			INT = 0,
    @MaxDuration			INT = 100000,
    @Campaigns				VARCHAR(MAX) = NULL,
 	@Agents					VARCHAR(MAX) = NULL,
   	@Origins				VARCHAR(100) = NULL,
	@DispositionCodes		VARCHAR(MAX) = NULL,
	@InteractionIds         VARCHAR(MAX) = NULL,
	--@Evaluated              VARCHAR(MAX) = NULL,
	@IsSummary				BIT = 0								-- ESTE FLAG TIENE COMO PROPOSITO RETORNAR LA LISTA CONSOLIDAD POR IDS O EL TOTAL DEL LISTADO
) 
AS
BEGIN
	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NULL OR @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NULL OR @EndHour = '') SET @EndHour = '23:59:59'

	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE MINIMO Y MAXIMO
	IF (@MinDuration IS NULL OR @MinDuration = '') SET @MinDuration = 0
	IF (@MaxDuration IS NULL OR @MaxDuration = '') SET @MaxDuration = 100000
	
	-- DECLARAMOS UN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = '';
	DECLARE @SQL_SELECT_0 VARCHAR(MAX) = '';
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';
    DECLARE @FILTERS_OPTIONAL_PART  VARCHAR(MAX) = '';
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = '';
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = '';
   -- DECLARE @QUERY_JOIN            VARCHAR(MAX) = '';

	-- HACEMOS EL SELECT SEGUN EL TIPO DE BUSQUEDA SETTEADO
	IF @IsSummary = 1 
	BEGIN
		-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
		SET @SQL_SELECT_0 += '
			SELECT ''CALL''											AS ''interactionType'', 
					COUNT(DISTINCT PCT.[ID])						AS ''totalInteractions'',
					COUNT(*)										AS ''details'',
					ISNULL(SUM(PCT.[DurationTime]), 0)				AS ''totalAttentionTime''
		'

		-- SETTEAMOS EL SELECT A LA VARIABLE FINAL
		SET @SQL_SELECT = @SQL_SELECT_0
	END
	ELSE
	BEGIN
		-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
		SET @SQL_SELECT_1 += '
			SELECT PCT.[ID] + ''_0_0''													''ID'',
					PCT.[ID]															''InteractionId'',
					0																	''Section'',
					0																	''Part'',
					''CALL''															''Channel'',
					PCT.[Number]														''Number'',
					PCT.[Gender]														''Gender'',
					PCT.[SilenceTime]													''SilenceTime'',
					PCT.[DurationTime]													''DurationTime'',
					PCT.[DurationTime]													''AttentionTime'',
					PCT.[Category1]														''Category1'',
					PCT.[Category2]														''Category2'',
					PCT.[Category3]														''Category3'',
					PCT.[Description]													''Description'',
					PCT.[DispositionCode]												''DispositionCode'',
					PCT.[Campaign]														''Campaign'',
					PCT.[Agent]															''Agent'',
					NULL																''agentName'',
					PCT.[Direction]														''Direction'', -- CAMBIAR POR TYPE
					CONVERT(VARCHAR, PCT.[StartDate], 120)								''StartDate'',
					CONVERT(VARCHAR, PCT.[EndDate], 120)								''EndDate'',
					NULL																''Format'',
					PCT.[RelativePath]													''RelativePath'',
					PCT.[RelativeFileName]												''RelativeFileName''
		'

		-- SETTEAMOS EL SELECT A LA VARIABLE FINAL
		SET @SQL_SELECT = @SQL_SELECT_1
	END
	
	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += ' FROM [#ProcessCsvTemp] PCT '

	-- FILTRO POR INTERACCIONES EVALUADAS O NO
	/*IF(@Evaluated IS NOT NULL AND @Evaluated <> '')
	  BEGIN 
	   DECLARE @EvaluatedTable TABLE (Val BIT)
	   INSERT INTO @EvaluatedTable SELECT Value FROM [dbo].[split]( @Evaluated ,',')
       -- SOLAMENTE SI ES SI O NO
       IF((SELECT COUNT(Val) FROM @EvaluatedTable) = 1 )
       BEGIN
          IF((SELECT Val FROM @EvaluatedTable WHERE Val = 1) IS NOT NULL) -- Si  es Si
           BEGIN 
               SET @QUERY_JOIN = ' JOIN [dbo].[AuditorEvaluationPlan] AEP ON (AEP.[IdInteraction] = PCT.[ID] AND AEP.[Completed]=1 ) '
           END
          ELSE  --Si es No
           BEGIN
               SET @QUERY_JOIN = ' LEFT JOIN [dbo].[AuditorEvaluationPlan] AEP ON (AEP.[IdInteraction] = PCT.[ID] AND AEP.[Completed]=1 ) '
               SET @FILTERS_OPTIONAL_PART += ' AND AEP.[IdInteraction] IS NULL '
           END
       END
       
	 END*/
	-- FIN FILTRO INTERACCIONES EVALUADAS
	

	-- ARMAMOS LA PARTE DE FILTROS
	SET @FILTERS_FIXED_PART = ' WHERE PCT.[ID] IS NOT NULL ';
    SET @FILTERS_OPTIONAL_PART += '
				AND PCT.[EndDate] BETWEEN ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + ''' AND ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + ''' 
				AND PCT.[DurationTime] BETWEEN ' + (SELECT CONVERT(VARCHAR(10), @MinDuration)) + ' AND ' + (SELECT CONVERT(VARCHAR(10), @MaxDuration)) + ' ';

	-- CONTINUAMOS CON LOS DEMAS FILTROS RECIBIDOS
	IF (@Campaigns IS NOT NULL AND @Campaigns != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND PCT.[Campaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	
	IF (@Agents IS NOT NULL AND @Agents != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND PCT.[Agent] IN (SELECT Value FROM [dbo].[split](''' + @Agents + ''','','')) '
	
	IF (@Origins IS NOT NULL AND @Origins != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND PCT.[Direction] IN (SELECT Value FROM [dbo].[split](''' + @Origins + ''','','')) '
	
	IF (@DispositionCodes IS NOT NULL AND @DispositionCodes != '') 
		--SET @FILTERS_OPTIONAL_PART += 'AND PCT.[DispositionCode] IN (SELECT Value FROM [dbo].[split](''' + @DispositionCodes + ''','','')) '
		SET @FILTERS_OPTIONAL_PART += ' 
			AND (
				(CONCAT(PCT.[Campaign], ''_'', ISNULL(CONVERT(VARCHAR(4), PCT.[DispositionCode]), '''')) IN (SELECT Value FROM [dbo].[split](''' + @DispositionCodes + ''','',''))) 
				OR
				(PCT.[Description] IN (SELECT Value FROM [dbo].[split](''' + @DispositionCodes + ''','','')))
			) '

	-- PARA EL CASO EN QUE HORA DE INICIO Y FIN NO SEAN NULL
	IF @StartHour IS NOT NULL AND @EndHour IS NOT NULL
	BEGIN
		IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) 
			SET @FILTERS_OPTIONAL_PART += 'AND CAST(PCT.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' '
		IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) 
			SET @FILTERS_OPTIONAL_PART += 'AND CAST(PCT.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO NO SEA NULL Y FIN SEA NULL
	ELSE IF @StartHour IS NOT NULL AND @EndHour IS NULL
	BEGIN
		SET @FILTERS_OPTIONAL_PART += 'AND CAST(PCT.[EndDate] AS TIME) > ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO SEA NULL Y FIN NO SEA NULL
	ELSE IF @StartHour IS NULL AND @EndHour IS NOT NULL
	BEGIN
		SET @FILTERS_OPTIONAL_PART += 'AND CAST(PCT.[EndDate] AS TIME) < ''' + @EndHour + ''' '
	END

    IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
    BEGIN
         SET @FILTERS_OPTIONAL_PART = '';
         --SET @QUERY_JOIN = '';
	     SET @FILTERS_EXCLUDING_PART = ' AND PCT.[ID] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) '
		 -- SET @FILTERS_EXCLUDING_PART = ' AND PCT.[ID] LIKE ''%' + @InteractionIds + '%'' '
	END	  
	-- ELIMINAMOS LA TABLA TEMPORAL DESPUES DE EJECUTAR EL QUERY
	SET @SQL_EXTRA += ' DROP TABLE [#ProcessCsvTemp] '
	
	-- UNIMOS LAS PARTES DEL QUERY
	--SET @SQL_SELECT += @SQL_FROM + @QUERY_JOIN + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA;
    SET @SQL_SELECT += @SQL_FROM  + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA;
	-- EJECUTAMOS LA CONSULTA

	EXEC (@SQL_SELECT)
	
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_7.4.0_database.tar.gz: database/mssql/procedures/GetCSVSummaryInteractions.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetCSVSummaryInteractions] 
(
	@VCC					VARCHAR(50) = NULL,
	@StartDate				DATETIME = '1980-01-01T00:00:00',
    @EndDate				DATETIME = '2050-01-01T23:59:59',
	@StartHour				VARCHAR(50) = NULL,
	@EndHour				VARCHAR(50) = NULL,
	@MinDuration			INT = 0,
    @MaxDuration			INT = 100000,
    @Campaigns				VARCHAR(MAX) = NULL,
 	@Agents					VARCHAR(MAX) = NULL,
   	@Origins				VARCHAR(100) = NULL,
	@DispositionCodes		VARCHAR(MAX) = NULL,
	@InteractionIds         VARCHAR(MAX) = NULL,
	--@Evaluated              VARCHAR(MAX) = NULL,
	@IsSummary				BIT = 0	,							-- ESTE FLAG TIENE COMO PROPOSITO RETORNAR LA LISTA CONSOLIDAD POR IDS O EL TOTAL DEL LISTADO
	@LimitIntByAgent		INT = 0
) 
AS
BEGIN
	
	
	DECLARE @SQL_SELECT_AGENTS VARCHAR(MAX) = '';
	IF @LimitIntByAgent > 0
	BEGIN 
		CREATE TABLE #Agents(
		 [agent] VARCHAR(200)
		)

		INSERT INTO #Agents
		SELECT DISTINCT agent FROM ProcessCsvTemp

		IF (@Agents ='')
		SET @SQL_SELECT_AGENTS+= 'SELECT [agent] FROM [#Agents] '

		CREATE TABLE #EnumProcessCsvTemp
		(
			[AgentNumber] INT,
			[ID] VarChar(100),
			[Number] VarChar(50),
			[Gender] VarChar(50),
			[SilenceTime] Int,
			[DurationTime] Int,
			[Category1] VarChar(50),
			[Category2] VarChar(50),
			[Category3] VarChar(50),
			[Description] VarChar(100),
			[Campaign] VarChar(100),
			[Agent] VarChar(50),
			[Direction] VarChar(50),
			[StartDate] DateTime,
			[EndDate] DateTime,
			[DispositionCode] VarChar(50),
			[RelativePath] VarChar(500),
			[RelativeFileName] VarChar(200)
		)

		

		INSERT INTO #EnumProcessCsvTemp
		SELECT
			ROW_NUMBER() OVER (PARTITION BY Agent ORDER BY StartDate) AS RowNumber,
			ID,
			Number,
			Gender,
			SilenceTime,
			DurationTime,
			Category1,
			Category2,
			Category3,
			Description,
			Campaign,
			Agent,
			Direction,
			StartDate,
			EndDate,
			DispositionCode,
			RelativePath,
			RelativeFileName
		FROM
			#ProcessCsvTemp

	

	END


	

	
	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NULL OR @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NULL OR @EndHour = '') SET @EndHour = '23:59:59'

	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE MINIMO Y MAXIMO
	IF (@MinDuration IS NULL OR @MinDuration = '') SET @MinDuration = 0
	IF (@MaxDuration IS NULL OR @MaxDuration = '') SET @MaxDuration = 100000
	
	-- DECLARAMOS UN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = '';
	DECLARE @SQL_SELECT_0 VARCHAR(MAX) = '';
	
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';
    DECLARE @FILTERS_OPTIONAL_PART  VARCHAR(MAX) = '';
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = '';
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = '';
   -- DECLARE @QUERY_JOIN            VARCHAR(MAX) = '';

	-- HACEMOS EL SELECT SEGUN EL TIPO DE BUSQUEDA SETTEADO
	IF @IsSummary = 1 
	BEGIN
		-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
		SET @SQL_SELECT_0 += '
			SELECT ''CALL''											AS ''interactionType'', 
					COUNT(DISTINCT PCT.[ID])						AS ''totalInteractions'',
					COUNT(*)										AS ''details'',
					ISNULL(SUM(PCT.[DurationTime]), 0)				AS ''totalAttentionTime''
					'

			
		 
		

		-- SETTEAMOS EL SELECT A LA VARIABLE FINAL
		SET @SQL_SELECT = @SQL_SELECT_0
	END
	ELSE
	BEGIN
		-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
		SET @SQL_SELECT_1 += '
			SELECT PCT.[ID] + ''_0_0''													''ID'',
					PCT.[ID]															''InteractionId'',
					0																	''Section'',
					0																	''Part'',
					''CALL''															''Channel'',
					PCT.[Number]														''Number'',
					PCT.[Gender]														''Gender'',
					PCT.[SilenceTime]													''SilenceTime'',
					PCT.[DurationTime]													''DurationTime'',
					PCT.[DurationTime]													''AttentionTime'',
					PCT.[Category1]														''Category1'',
					PCT.[Category2]														''Category2'',
					PCT.[Category3]														''Category3'',
					PCT.[Description]													''Description'',
					PCT.[DispositionCode]												''DispositionCode'',
					PCT.[Campaign]														''Campaign'',
					PCT.[Agent]															''Agent'',
					NULL																''agentName'',
					PCT.[Direction]														''Direction'', -- CAMBIAR POR TYPE
					CONVERT(VARCHAR, PCT.[StartDate], 120)								''StartDate'',
					CONVERT(VARCHAR, PCT.[EndDate], 120)								''EndDate'',
					NULL																''Format'',
					PCT.[RelativePath]													''RelativePath'',
					PCT.[RelativeFileName]												''RelativeFileName''
		'

		-- SETTEAMOS EL SELECT A LA VARIABLE FINAL
		SET @SQL_SELECT = @SQL_SELECT_1
	END
	
	-- ARMAMOS LA PARTE DE TABLAS 
	IF @LimitIntByAgent > 0
	SET @SQL_FROM += ' FROM [#EnumProcessCsvTemp] PCT ' 
	ELSE
	SET @SQL_FROM += ' FROM [#ProcessCsvTemp] PCT '

	-- FILTRO POR INTERACCIONES EVALUADAS O NO
	/*IF(@Evaluated IS NOT NULL AND @Evaluated <> '')
	  BEGIN 
	   DECLARE @EvaluatedTable TABLE (Val BIT)
	   INSERT INTO @EvaluatedTable SELECT Value FROM [dbo].[split]( @Evaluated ,',')
       -- SOLAMENTE SI ES SI O NO
       IF((SELECT COUNT(Val) FROM @EvaluatedTable) = 1 )
       BEGIN
          IF((SELECT Val FROM @EvaluatedTable WHERE Val = 1) IS NOT NULL) -- Si  es Si
           BEGIN 
               SET @QUERY_JOIN = ' JOIN [dbo].[AuditorEvaluationPlan] AEP ON (AEP.[IdInteraction] = PCT.[ID] AND AEP.[Completed]=1 ) '
           END
          ELSE  --Si es No
           BEGIN
               SET @QUERY_JOIN = ' LEFT JOIN [dbo].[AuditorEvaluationPlan] AEP ON (AEP.[IdInteraction] = PCT.[ID] AND AEP.[Completed]=1 ) '
               SET @FILTERS_OPTIONAL_PART += ' AND AEP.[IdInteraction] IS NULL '
           END
       END
       
	 END*/
	-- FIN FILTRO INTERACCIONES EVALUADAS
	

	-- ARMAMOS LA PARTE DE FILTROS
	SET @FILTERS_FIXED_PART = ' WHERE PCT.[ID] IS NOT NULL ';
    SET @FILTERS_OPTIONAL_PART += '
				AND PCT.[EndDate] BETWEEN ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + ''' AND ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + ''' 
				AND PCT.[DurationTime] BETWEEN ' + (SELECT CONVERT(VARCHAR(10), @MinDuration)) + ' AND ' + (SELECT CONVERT(VARCHAR(10), @MaxDuration)) + ' ';

	-- CONTINUAMOS CON LOS DEMAS FILTROS RECIBIDOS
	IF (@Campaigns IS NOT NULL AND @Campaigns != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND PCT.[Campaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	
	IF (@Agents IS NOT NULL AND @Agents != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND PCT.[Agent] IN (SELECT Value FROM [dbo].[split](''' + @Agents + ''','','')) '
	
	IF (@Origins IS NOT NULL AND @Origins != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND PCT.[Direction] IN (SELECT Value FROM [dbo].[split](''' + @Origins + ''','','')) '
	
	IF (@DispositionCodes IS NOT NULL AND @DispositionCodes != '') 
		--SET @FILTERS_OPTIONAL_PART += 'AND PCT.[DispositionCode] IN (SELECT Value FROM [dbo].[split](''' + @DispositionCodes + ''','','')) '
		SET @FILTERS_OPTIONAL_PART += ' 
			AND (
				(CONCAT(PCT.[Campaign], ''_'', ISNULL(CONVERT(VARCHAR(4), PCT.[DispositionCode]), '''')) IN (SELECT Value FROM [dbo].[split](''' + @DispositionCodes + ''','',''))) 
				OR
				(PCT.[Description] IN (SELECT Value FROM [dbo].[split](''' + @DispositionCodes + ''','','')))
			) '
	IF(@LimitIntByAgent > 0)
		SET @FILTERS_OPTIONAL_PART +=  'AND [AgentNumber] <= ' +  CAST(@LimitIntByAgent AS VARCHAR) + ' '

	-- PARA EL CASO EN QUE HORA DE INICIO Y FIN NO SEAN NULL
	IF @StartHour IS NOT NULL AND @EndHour IS NOT NULL
	BEGIN
		IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) 
			SET @FILTERS_OPTIONAL_PART += 'AND CAST(PCT.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' '
		IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) 
			SET @FILTERS_OPTIONAL_PART += 'AND CAST(PCT.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO NO SEA NULL Y FIN SEA NULL
	ELSE IF @StartHour IS NOT NULL AND @EndHour IS NULL
	BEGIN
		SET @FILTERS_OPTIONAL_PART += 'AND CAST(PCT.[EndDate] AS TIME) > ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO SEA NULL Y FIN NO SEA NULL
	ELSE IF @StartHour IS NULL AND @EndHour IS NOT NULL
	BEGIN
		SET @FILTERS_OPTIONAL_PART += 'AND CAST(PCT.[EndDate] AS TIME) < ''' + @EndHour + ''' '
	END

    IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
    BEGIN
         SET @FILTERS_OPTIONAL_PART = '';
         --SET @QUERY_JOIN = '';
	     SET @FILTERS_EXCLUDING_PART = ' AND PCT.[ID] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) '
		 -- SET @FILTERS_EXCLUDING_PART = ' AND PCT.[ID] LIKE ''%' + @InteractionIds + '%'' '
	END	  
	-- ELIMINAMOS LA TABLA TEMPORAL DESPUES DE EJECUTAR EL QUERY
	IF @LimitIntByAgent > 0
	SET @SQL_EXTRA += ' DROP TABLE [#ProcessCsvTemp]  DROP TABLE  [#EnumProcessCsvTemp] DROP TABLE [#Agents]'
	ELSE
	SET @SQL_EXTRA += ' DROP TABLE [#ProcessCsvTemp] '
	
	-- UNIMOS LAS PARTES DEL QUERY
	--SET @SQL_SELECT += @SQL_FROM + @QUERY_JOIN + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA;
    SET @SQL_SELECT += @SQL_FROM  + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_SELECT_AGENTS + @SQL_EXTRA;
	-- EJECUTAMOS LA CONSULTA
	--PRINT @SQL_SELECT
	EXEC (@SQL_SELECT)
	
END	

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
